@@ -18,12 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class UpdateDnsGtmAccessStrategyRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'UpdateDnsGtmAccessStrategy','alidns')
 		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_DefaultLbaStrategy(self):
 		return self.get_query_params().get('DefaultLbaStrategy')
@@ -127,4 +133,10 @@ class UpdateDnsGtmAccessStrategyRequest(RpcRequest):
 			if FailoverAddrPools[depth1].get('Id') is not None:
 				self.add_query_param('FailoverAddrPool.' + str(depth1 + 1) + '.Id', FailoverAddrPools[depth1].get('Id'))
 			if FailoverAddrPools[depth1].get('LbaWeight') is not None:
-				self.add_query_param('FailoverAddrPool.' + str(depth1 + 1) + '.LbaWeight', FailoverAddrPools[depth1].get('LbaWeight'))
\ No newline at end of file
+				self.add_query_param('FailoverAddrPool.' + str(depth1 + 1) + '.LbaWeight', FailoverAddrPools[depth1].get('LbaWeight'))
+
+	def get_AccessMode(self):
+		return self.get_query_params().get('AccessMode')
+
+	def set_AccessMode(self,AccessMode):
+		self.add_query_param('AccessMode',AccessMode)
\ No newline at end of file
