@@ -18,12 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class UpdateDnsGtmInstanceGlobalConfigRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'UpdateDnsGtmInstanceGlobalConfig','alidns')
 		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_AlertGroup(self):
 		return self.get_query_params().get('AlertGroup')
@@ -48,6 +54,8 @@ class UpdateDnsGtmInstanceGlobalConfigRequest(RpcRequest):
 
 	def set_AlertConfigs(self, AlertConfigs):
 		for depth1 in range(len(AlertConfigs)):
+			if AlertConfigs[depth1].get('DingtalkNotice') is not None:
+				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.DingtalkNotice', AlertConfigs[depth1].get('DingtalkNotice'))
 			if AlertConfigs[depth1].get('SmsNotice') is not None:
 				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.SmsNotice', AlertConfigs[depth1].get('SmsNotice'))
 			if AlertConfigs[depth1].get('NoticeType') is not None:
@@ -73,6 +81,12 @@ class UpdateDnsGtmInstanceGlobalConfigRequest(RpcRequest):
 	def set_Ttl(self,Ttl):
 		self.add_query_param('Ttl',Ttl)
 
+	def get_ForceUpdate(self):
+		return self.get_query_params().get('ForceUpdate')
+
+	def set_ForceUpdate(self,ForceUpdate):
+		self.add_query_param('ForceUpdate',ForceUpdate)
+
 	def get_InstanceId(self):
 		return self.get_query_params().get('InstanceId')
 
@@ -85,6 +99,12 @@ class UpdateDnsGtmInstanceGlobalConfigRequest(RpcRequest):
 	def set_InstanceName(self,InstanceName):
 		self.add_query_param('InstanceName',InstanceName)
 
+	def get_PublicRr(self):
+		return self.get_query_params().get('PublicRr')
+
+	def set_PublicRr(self,PublicRr):
+		self.add_query_param('PublicRr',PublicRr)
+
 	def get_PublicZoneName(self):
 		return self.get_query_params().get('PublicZoneName')
 
